@@ -3,6 +3,18 @@ from wiggles.symbols import *
 import numpy as np
 import sympy.core.numbers as symnum
 import sympy.functions as symfun
+import pickle
+
+#Exports Wiggles type signal to a file
+def export_wiggles(wiggles_obj, file_path):
+    with open(file_path, 'wb') as f:
+        pickle.dump(wiggles_obj, f)
+
+#Imports Wiggles type signal from a file
+def import_wiggles(file_path):
+    with open(file_path, 'rb') as f:
+        wiggles_obj = pickle.load(f)
+    return wiggles_obj
 
 def unit_step(n):
     return Heaviside(n)
