@@ -4,6 +4,20 @@ import copy
 import random
 import sympy.core.numbers as symnum
 import sympy.functions as symfun
+import pickle
+from sympy import symbols
+from symbols import *
+
+#Exports Wiggles type signal to a file
+def export_wiggles(wiggles_obj, file_path):
+    with open(file_path, 'wb') as f:
+        pickle.dump(wiggles_obj, f)
+
+#Imports Wiggles type signal from a file
+def import_wiggles(file_path):
+    with open(file_path, 'rb') as f:
+        wiggles_obj = pickle.load(f)
+    return wiggles_obj
 
 #Class to build discrete signals
 class discrete():
@@ -28,6 +42,126 @@ class discrete():
     x = []
     t = []
     
+    #Convert to symbols 
+    def to_symbols(self):
+        if(self.domain == 'time'):
+            X = list(self.t)
+            Y = list(self.x)
+
+            x = symbols('t')
+            n = len(Y)
+            t = 0
+            for i in range(n):
+                p = Y[i]
+                for j in range(n):
+                    if i == j:
+                        continue
+                    p *= (x - X[j]) / (X[i] - X[j])
+                t += p
+            return time_domain(func=None,sympy_exp=t,name=self.name)
+        else:
+            X = list(self.t)
+            Y = list(self.x)
+            
+            x = symbols('s')
+            n = len(Y)
+            t = 0
+            for i in range(n):
+                p = Y[i]
+                for j in range(n):
+                    if i == j:
+                        continue
+                    p *= (x - X[j]) / (X[i] - X[j])
+                t += p
+            return frequency_domain(func=None,sympy_exp=t,name=self.name)
+
+    #Exports Wiggles type signal to SciLab Syntax
+    def to_scilab(self):
+        x_scilab_string = self.ylabel+'=['
+        t_scilab_string = self.xlabel+'=['
+        for item in self.x:
+            x_scilab_string += str(item) + ', '
+        for item in self.t:
+            t_scilab_string += str(item) + ', '
+        x_scilab_string = x_scilab_string[0:-2]
+        t_scilab_string = t_scilab_string[0:-2]
+        x_scilab_string += '];'
+        t_scilab_string += '];'
+        print (x_scilab_string)
+        print (t_scilab_string)
+
+    #Exports Wiggles type signal to Matlab Syntax
+    def to_matlab(self):
+        x_scilab_string = self.ylabel+'=['
+        t_scilab_string = self.xlabel+'=['
+        for item in self.x:
+            x_scilab_string += str(item) + ', '
+        for item in self.t:
+            t_scilab_string += str(item) + ', '
+        x_scilab_string = x_scilab_string[0:-2]
+        t_scilab_string = t_scilab_string[0:-2]
+        x_scilab_string += '];'
+        t_scilab_string += '];'
+        print (x_scilab_string)
+        print (t_scilab_string)
+
+    #Exports Wiggles type signal to C Syntax
+    def to_c(self):
+        x_c_string = 'float '+ self.ylabel+'[]= {'
+        t_c_string = 'float '+ self.xlabel+'[]= {'
+        for item in self.x:
+            x_c_string += str(item) + ', '
+        for item in self.t:
+            t_c_string += str(item) + ', '
+        x_c_string = x_c_string[0:-2]
+        t_c_string = t_c_string[0:-2]
+        x_c_string += '};'
+        t_c_string += '};'
+        print (x_c_string)
+        print (t_c_string)
+
+    #Exports Wiggles type signal to cpp Syntax
+    def to_cpp(self):
+        x_cpp_string = 'float '+ self.ylabel+'[]= {'
+        t_cpp_string = 'float '+ self.xlabel+'[]= {'
+        for item in self.x:
+            x_cpp_string += str(item) + ', '
+        for item in self.t:
+            t_cpp_string += str(item) + ', '
+        x_cpp_string = x_cpp_string[0:-2]
+        t_cpp_string = t_cpp_string[0:-2]
+        x_cpp_string += '};'
+        t_cpp_string += '};'
+        print (x_cpp_string)
+        print (t_cpp_string)
+
+    #Exports Wiggles type signal to Java Syntax
+    def to_java(self):
+        x_java_string = 'float[] '+ self.ylabel+'= {'
+        t_java_string = 'float[] '+ self.xlabel+'= {'
+        for item in self.x:
+            x_java_string += str(item) + ', '
+        for item in self.t:
+            t_java_string += str(item) + ', '
+        x_java_string = x_java_string[0:-2]
+        t_java_string = t_java_string[0:-2]
+        x_java_string += '};'
+        t_java_string += '};'
+        print (x_java_string)
+        print (t_java_string)
+
+    #Exports Wiggles type signal to a csv file
+    def to_csv(self, file_path):
+        with open(file_path, 'w') as f:
+            f.write(self.xlabel + ',' + self.ylabel + '\n')
+            for xi, yi in zip(self.t, self.x):
+                f.write(str(xi) + ',' + str(yi) + '\n')
+
+    #Exports Wiggles type signal to a file
+    def export_wiggles(self, file_path):
+        with open(file_path, 'wb') as f:
+            pickle.dump(self, f)
+
     #Gets invoked on object creation
     def __init__(self, signal, start=0,step=1,time = [None],name=chr(random.randint(ord('a'), ord('z')))):
 
@@ -1400,6 +1534,20 @@ class discrete():
             else:
                 break
 
+    #Convert to frequency domain using fft algorithm
+    def fft(self):
+        change = copy.deepcopy(self)
+        change.x = np.fft.fft(change.x)
+        change.t = np.fft.fftfreq(len(change.x), d=(change.t[1]-change.t[0]))
+        change.xlabel = "Frequency"
+        change.ylabel = "Amplitude"
+        return change
+    
+    #Convert to frequency domain
+    def to_frequency_domain(self):
+        return self.fft()
+
+
 #Create unit impulse signals easily
 class unit_impulse(discrete):
 
@@ -1559,3 +1707,5 @@ class carray(continuous):
     def __init__(self,signal=None, start=0, stop=1, step=0.001, time=[None],func=None,name="arr" + str(random.randint(0, 100))):
         super().__init__(func, list(signal), start, stop, step, time, name)
 
+
+
